AdaptiveOverlayPage<T> class

Inheritance

Constructors

AdaptiveOverlayPage({required Widget child, bool? showDragHandle = false, bool useSafeArea = true, bool isScrollControlled = true, TraversalEdgeBehavior? traversalEdgeBehavior, Offset? anchorPoint, Color? barrierColor, bool barrierDismissible = true, String? barrierLabel, String? barrierOnTapHint, CapturedThemes? capturedThemes, Clip? clipBehavior = Clip.none, bool enableDrag = true, BoxConstraints? constraints, double? elevation, bool? requestFocus, double scrollControlDisabledMaxHeightRatio = 9.0 / 16.0, ShapeBorder? shape = const RoundedRectangleBorder(borderRadius: BorderRadius.only(topLeft: Radius.circular(24), topRight: Radius.circular(24))), AnimationStyle? sheetAnimationStyle, AnimationController? transitionAnimationController, String? name, Object? arguments, String? restorationId, LocalKey? key, double? heightFactor = 0.98})
const

Properties

anchorPoint Offset?
final
arguments Object?
The arguments passed to this route.
finalinherited
barrierColor Color?
final
barrierDismissible bool
final
barrierLabel String?
final
barrierOnTapHint String?
final
canPop bool
When false, blocks the associated route from being popped.
finalinherited
capturedThemes CapturedThemes?
final
child Widget
final
clipBehavior Clip?
final
constraints BoxConstraints?
final
elevation double?
final
enableDrag bool
final
hashCode int
The hash code for this object.
no setterinherited
heightFactor double?
final
isScrollControlled bool
final
key LocalKey?
The key associated with this page.
finalinherited
name String?
The name of the route (e.g., "/settings").
finalinherited
onPopInvoked PopInvokedWithResultCallback<T>
Called after a pop on the associated route was handled.
finalinherited
requestFocus bool?
final
restorationId String?
Restoration ID to save and restore the state of the Route configured by this page.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollControlDisabledMaxHeightRatio double
final
shape ShapeBorder?
final
sheetAnimationStyle AnimationStyle?
final
showDragHandle bool?
final
transitionAnimationController AnimationController?
final
traversalEdgeBehavior TraversalEdgeBehavior?
final
useSafeArea bool
final

Methods

canUpdate(Page other) bool
Whether this page can be updated with the other page.
inherited
createRoute(BuildContext context) Route<T>
Creates the Route that corresponds to this page.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited