AutoGoRouteBase class

Annotation for route base class that collects all routes

Constructors

AutoGoRouteBase({String? initialLocation, String? errorBuilder, String? redirect, String navigatorExtensionName = 'AutoGoRouteNavigation'})
const

Properties

errorBuilder String?
final
hashCode int
The hash code for this object.
no setterinherited
initialLocation String?
final
The name for the generated BuildContext navigation extension.
final
redirect String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited