AutoGoRouteShell class

Annotation for a ShellRoute

Constructors

AutoGoRouteShell({required String path, String? name, String? description, String? navigatorKey, Type? parent, bool isStateful = false, String? initialRoute, int? order, String? pageBuilder})
const

Properties

description String?
final
hashCode int
The hash code for this object.
no setterinherited
initialRoute String?
The absolute path to redirect to when this shell is navigated to directly. If not provided for a root shell (path: '/'), it defaults to the path of the first child route.
final
isStateful bool
final
name String?
final
final
order int?
The index of this shell when used as a branch in a StatefulShellRoute.
final
pageBuilder String?
The name of a top-level or static function that returns a Page to customize the shell's appearance and transition. e.g., 'adaptiveOverlayPageBuilder'. Only applicable when isStateful is false.
final
parent Type?
final
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited