RouteMetadata class
Route metadata for documentation and analysis
Constructors
-
RouteMetadata({required String path, String? name, String? description, required List<
String> requiredParams, required List<String> optionalParams, required DateTime registeredAt}) - RouteMetadata.fromRoute(RoutePaths route)
-
factory
Properties
- description → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String?
-
final
-
optionalParams
→ List<
String> -
final
- path → String
-
final
- registeredAt → DateTime
-
final
-
requiredParams
→ List<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited