RoutePaths class abstract

Base class for all route definitions

Implementers

Constructors

RoutePaths({required String path, String? name, required Widget builder(BuildContext, GoRouterState), String? description, List<FutureOr<String?> Function(BuildContext, GoRouterState)> middleware = const []})
const

Properties

builder Widget Function(BuildContext, GoRouterState)
Widget builder function
final
description String?
Route description for documentation
final
hashCode int
The hash code for this object.
no setterinherited
middleware List<FutureOr<String?> Function(BuildContext, GoRouterState)>
Middleware functions
final
name String?
Optional route name
final
optionalParams List<String>
Auto-detect optional parameters from path
no setter
path String
The route path with parameters
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
requiredParams List<String>
Auto-detect required parameters from path
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pathWithParams(Map<String, String> params, {Map<String, String>? queries, bool validate = true}) String
Generate path with parameters
toGoRoute({List<RouteBase> routes = const []}) → GoRoute
Generate GoRoute
toString() String
A string representation of this object.
validateParams(Map<String, String> params) → void
Validate parameters

Operators

operator ==(Object other) bool
The equality operator.
inherited