RouteValidationException class

Exception thrown when route validation fails

Inheritance

Constructors

RouteValidationException(String message, String? routePath)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
finalinherited
routePath String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited