RouteValidationResult class

Route validation result

Constructors

RouteValidationResult({required bool isValid, List<String> errors = const [], List<String> warnings = const []})
const
RouteValidationResult.invalid(List<String> errors, [List<String>? warnings])
factory
RouteValidationResult.valid()
factory

Properties

errors List<String>
final
hashCode int
The hash code for this object.
no setterinherited
isValid bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
warnings List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited