NestedRoutePaths class abstract
Base class for nested route definitions
- Inheritance
-
- Object
- RoutePaths
- NestedRoutePaths
Constructors
-
NestedRoutePaths({required String parentPath, required String path, String? name, required Widget builder(BuildContext, GoRouterState), String? description, List<
FutureOr< middleware = const []})String?> Function(BuildContext, GoRouterState)> -
const
Properties
- builder → Widget Function(BuildContext, GoRouterState)
-
Widget builder function
finalinherited
- description → String?
-
Route description for documentation
finalinherited
- fullPath → String
-
Get the full absolute path, correctly joining parent and child paths.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
middleware
→ List<
FutureOr< String?> Function(BuildContext, GoRouterState)> -
Middleware functions
finalinherited
- name → String?
-
Optional route name
finalinherited
-
optionalParams
→ List<
String> -
Override to scan the
fullPathfor optional parameters.no setteroverride - parentPath → String
-
final
- path → String
-
The route path with parameters
finalinherited
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setteroverride
-
requiredParams
→ List<
String> -
Override to scan the
fullPathfor required parameters.no setteroverride - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pathWithParams(
Map< String, String> params, {Map<String, String> ? queries, bool validate = true}) → String -
Override
pathWithParamsto use thefullPathas the template.override -
toGoRoute(
{List< RouteBase> routes = const []}) → GoRoute -
Generate GoRoute
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validateParams(
Map< String, String> params) → void -
Validate parameters
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited