RouteRegistry class
Central registry for all application routes
Constructors
- RouteRegistry()
-
factory
Properties
-
allRouteNames
→ List<
String> -
Get all route names
no setter
-
allRoutes
→ List<
RoutePaths> -
Get all registered routes
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statistics → RegistryStatistics
-
Get registry statistics
no setter
Methods
-
clear(
) → void - Clear all registered routes
-
generateDocumentation(
{bool includeMetadata = true, bool includeParameters = true, bool includeExamples = true, DocumentationFormat format = DocumentationFormat.markdown}) → String - Generate comprehensive documentation
-
generateGoRoutes(
{String? globalRedirect(BuildContext, GoRouterState)?}) → List< GoRoute> - Generate GoRouter routes
-
getRoute(
String identifier) → RoutePaths? - Get route by name or path
-
getRouteGroup(
String groupName) → List< RoutePaths> ? - Get routes by group
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
register(
RoutePaths route) → void - Register a single route
-
registerAll(
List< RoutePaths> routes) → void - Register multiple routes
-
registerGroup(
String groupName, List< RoutePaths> routes) → void - Register routes in a group
-
toString(
) → String -
A string representation of this object.
inherited
-
validateAllRoutes(
) → void - Validate all registered routes
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited