ShellRoutePaths class abstract
Base class for shell route definitions
Constructors
- ShellRoutePaths({required String path, String? name, required Widget builder(BuildContext, GoRouterState, Widget), String? description, bool isStateful = false})
-
const
Properties
- builder → Widget Function(BuildContext, GoRouterState, Widget)
-
final
- description → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isStateful → bool
-
final
- name → String?
-
final
-
final
- path → String
-
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toGoRoute(
{List< RouteBase> routes = const []}) → GoRoute - Generate regular GoRoute (fallback). This should ideally not be called directly for a shell.
-
toShellRoute(
{List< RouteBase> routes = const []}) → ShellRoute - Generate ShellRoute
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited