toGoRoute method
Generate regular GoRoute (fallback). This should ideally not be called directly for a shell.
Implementation
GoRoute toGoRoute({List<RouteBase> routes = const []}) {
return GoRoute(
path: path,
name: name,
builder: (context, state) {
assert(false,
'A ShellRoute was rendered without a child. This is usually an error in your routing setup.');
return const Scaffold(
body: Center(
child: Text('Error: ShellRoute rendered without a child widget.'),
),
);
},
routes: routes,
);
}